@@ -6,7 +6,7 @@ the Software are granted under this license.
 
 The Clear BSD License
 
-Copyright (c) 2018-2024, Fraunhofer-Gesellschaft zur Förderung der angewandten Forschung e.V. & The VVdeC Authors.
+Copyright (c) 2018-2025, Fraunhofer-Gesellschaft zur Förderung der angewandten Forschung e.V. & The VVdeC Authors.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification,
@@ -142,7 +142,7 @@ namespace vvdec
 // ====================================================================================================================
 
 // SIMD optimizations
-#define SIMD_ENABLE                                       1
+#define SIMD_ENABLE                                      1
 #define ENABLE_SIMD_OPT                                 ( SIMD_ENABLE )                                     ///< SIMD optimizations
 #define ENABLE_SIMD_OPT_MCIF                            ( 1 && ENABLE_SIMD_OPT )                            ///< SIMD optimization for the interpolation filter
 #define ENABLE_SIMD_OPT_BUFFER                          ( 1 && ENABLE_SIMD_OPT )                            ///< SIMD optimization for the buffer operations
@@ -743,8 +743,10 @@ public:
   virtual ~Exception() noexcept = default;
   CLASS_COPY_MOVE_DEFAULT( Exception )
 
-  virtual const char* what() const noexcept                 { return m_str.c_str(); }
-  template<typename T> Exception& operator<<( const T& t )  { std::ostringstream oss; oss << t; m_str += oss.str(); return *this; }
+  virtual const char* what() const noexcept  { return m_str.c_str(); }
+  template<typename T>
+  inline Exception& operator<<( const T& t ) { std::ostringstream oss; oss << t; m_str += oss.str(); return *this; }
+
 private:
   std::string m_str;
 };
@@ -755,6 +757,9 @@ public:
   explicit RecoverableException( const std::string& _s ) : Exception( _s ) {}
   virtual ~RecoverableException() noexcept = default;
   CLASS_COPY_MOVE_DEFAULT( RecoverableException )
+
+  template<typename T>
+  inline RecoverableException& operator<<( const T& t ) { static_cast<Exception&>( *this ) << t; return *this; }
 };
 
 class UnsupportedFeatureException : public Exception
@@ -763,6 +768,9 @@ public:
   explicit UnsupportedFeatureException( const std::string& _s ) : Exception( _s ) {}
   virtual ~UnsupportedFeatureException() noexcept = default;
   CLASS_COPY_MOVE_DEFAULT( UnsupportedFeatureException )
+
+  template<typename T>
+  inline UnsupportedFeatureException& operator<<( const T& t ) { static_cast<Exception&>( *this ) << t; return *this; }
 };
 
 #if defined( __MINGW32__ ) && !defined( __MINGW64__ )
@@ -993,9 +1001,7 @@ struct AlfSliceParam
     static_assert( offsetof( AlfSliceParam, recostructMutex ) + sizeof( recostructMutex ) == sizeof( AlfSliceParam ), "recostructMutex must be last member" );
     static_assert( std::is_standard_layout<AlfSliceParam>::value, "AlfSliceParam must be standard layout type for offsetof to work" );
 
-    GCC_WARNING_DISABLE_class_memaccess
-      memset( this, 0, offsetof( AlfSliceParam, recostructMutex ) );
-    GCC_WARNING_RESET
+    memset( NO_WARNING_class_memaccess( this ), 0, offsetof( AlfSliceParam, recostructMutex ) );
 
     numLumaFilters = 1;
     numAlternativesChroma = 1;
@@ -1003,9 +1009,7 @@ struct AlfSliceParam
 
   const AlfSliceParam& operator=( const AlfSliceParam& src )
   {
-    GCC_WARNING_DISABLE_class_memaccess
-      std::memcpy( this, &src, offsetof( AlfSliceParam, recostructMutex ) );
-    GCC_WARNING_RESET
+    std::memcpy( NO_WARNING_class_memaccess( this ), &src, offsetof( AlfSliceParam, recostructMutex ) );
 
     return *this;
   }
@@ -1026,14 +1030,15 @@ struct CcAlfFilterParam
 
   void reset()
   {
-    std::memset( this, 0, sizeof( *this ) );
+    std::memset( NO_WARNING_class_memaccess( this ), 0, sizeof( *this ) );
 
     ccAlfFilterCount[0] = ccAlfFilterCount[1] = MAX_NUM_CC_ALF_FILTERS;
   }
 
   const CcAlfFilterParam& operator=( const CcAlfFilterParam& src )
   {
-    std::memcpy( this, &src, sizeof( CcAlfFilterParam ) );
+    std::memcpy( NO_WARNING_class_memaccess( this ), &src, sizeof( CcAlfFilterParam ) );
+
     return *this;
   }
 };
