@@ -6,7 +6,7 @@ the Software are granted under this license.
 
 The Clear BSD License
 
-Copyright (c) 2018-2024, Fraunhofer-Gesellschaft zur Förderung der angewandten Forschung e.V. & The VVdeC Authors.
+Copyright (c) 2018-2025, Fraunhofer-Gesellschaft zur Förderung der angewandten Forschung e.V. & The VVdeC Authors.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification,
@@ -46,11 +46,11 @@ POSSIBILITY OF SUCH DAMAGE.
 #include "CommonDefX86.h"
 #include "../SampleAdaptiveOffset.h"
 
+#if defined(TARGET_SIMD_X86)  && ENABLE_SIMD_OPT_SAO
+
 namespace vvdec
 {
 
-#ifdef TARGET_SIMD_X86
-
 #  define SAO_NUM_OFFSETS 4                             /* number of SAO offset values */
 #  define SAO_EO_NUM_CATEGORIES ( SAO_NUM_OFFSETS + 1 ) /* number of different eo categories */
 
@@ -1353,6 +1353,6 @@ void SampleAdaptiveOffset::_initSampleAdaptiveOffsetX86()
 }
 
 template void SampleAdaptiveOffset::_initSampleAdaptiveOffsetX86<SIMDX86>();
-#endif   //#ifdef TARGET_SIMD_X86
 
 }
+#endif   //#ifdef TARGET_SIMD_X86
