@@ -6,7 +6,7 @@ the Software are granted under this license.
 
 The Clear BSD License
 
-Copyright (c) 2018-2024, Fraunhofer-Gesellschaft zur Förderung der angewandten Forschung e.V. & The VVdeC Authors.
+Copyright (c) 2018-2025, Fraunhofer-Gesellschaft zur Förderung der angewandten Forschung e.V. & The VVdeC Authors.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification,
@@ -83,7 +83,7 @@ int VVDecImpl::init( const vvdecParams& params, vvdecCreateBufferCallback create
 
   try
   {
-#ifdef TARGET_SIMD_X86
+#if defined(TARGET_SIMD_X86) && ENABLE_SIMD_OPT
     switch( params.simd )
     {
     case VVDEC_SIMD_SCALAR: read_x86_extension_flags( x86_simd::SCALAR ); break;
@@ -92,7 +92,7 @@ int VVDecImpl::init( const vvdecParams& params, vvdecCreateBufferCallback create
     case VVDEC_SIMD_SSE42 : read_x86_extension_flags( x86_simd::SSE42  ); break;
     case VVDEC_SIMD_AVX   : read_x86_extension_flags( x86_simd::AVX    ); break;
     case VVDEC_SIMD_AVX2  : read_x86_extension_flags( x86_simd::AVX2   ); break;
-#  elif defined( VVDEC_ARCH_ARM ) || defined( VVDEC_ARCH_WASM )
+#  elif defined( VVDEC_ARCH_ARM ) || defined( VVDEC_ARCH_WASM ) || defined( VVDEC_ARCH_LOONGARCH )
     case VVDEC_SIMD_MAX   : read_x86_extension_flags( SIMD_EVERYWHERE_EXTENSION_LEVEL ); break;
 #  endif
     case VVDEC_SIMD_DEFAULT:
@@ -100,7 +100,7 @@ int VVDecImpl::init( const vvdecParams& params, vvdecCreateBufferCallback create
     }
 #endif   // TARGET_SIMD_X86
 
-#ifdef TARGET_SIMD_ARM
+#if defined(TARGET_SIMD_ARM) && ENABLE_SIMD_OPT
     switch( params.simd )
     {
     case VVDEC_SIMD_SCALAR : read_arm_extension_flags( arm_simd::SCALAR );    break;
@@ -393,6 +393,9 @@ int VVDecImpl::decode( vvdecAccessUnit& rcAccessUnit, vvdecFrame** ppcFrame )
           if( rcAccessUnit.dtsValid ){  nalu.m_dts = rcAccessUnit.dts; }
           nalu.m_rap = rcAccessUnit.rap;
           nalu.m_bits = ( numNaluBytes + iStartCodeSizeVec[iAU] ) * 8;
+#if VVDEC_USE_UNSTABLE_API
+          nalu.m_userData = rcAccessUnit.userData;
+#endif
 
           pcPic = m_cDecLib->decode( nalu );
 
@@ -1057,11 +1060,24 @@ int VVDecImpl::xAddPicture( Picture* pcPic )
 
   cFrame.picAttributes->seqInfo->maxWidth  = pcPic->cs->sps->getMaxPicWidthInLumaSamples();
   cFrame.picAttributes->seqInfo->maxHeight = pcPic->cs->sps->getMaxPicHeightInLumaSamples();
+  int32_t maxReorderPics = 0;
+  uint32_t maxLatencyIncreasePlus1 = 0;
+  for(uint32_t i = 0; i < sps->getMaxTLayers(); i++) {
+    maxReorderPics = std::max(maxReorderPics, sps->getNumReorderPics(i));
+    maxLatencyIncreasePlus1 = std::max(maxLatencyIncreasePlus1, sps->getMaxLatencyIncreasePlus1(i));
+  }
+
+  cFrame.picAttributes->seqInfo->maxNumReorderPics = maxReorderPics;
+  cFrame.picAttributes->seqInfo->maxLatencyIncreasePlus1 = maxLatencyIncreasePlus1;
+
   cFrame.picAttributes->picHashError =
     pcPic->dphMismatch ? VVDEC_DPH_MISMATCH                                   // first check pcPic->dphMismatch,
                        : ( pcPic->picCheckedDPH ? VVDEC_DPH_OK                // and then pcPic->picCheckedDPH, because it will only be set when all subpics
                                                 : VVDEC_DPH_NOT_VERIFIED );   // have been checked, but the DPH-SEIs for some subpics could be missing,
 
+#if VVDEC_USE_UNSTABLE_API
+  cFrame.picAttributes->userData = pcPic->userData;
+#endif
   if( pcPic->fieldPic )
   {
     cFrame.frameFormat = pcPic->topField ? VVDEC_FF_TOP_FIELD : VVDEC_FF_BOT_FIELD;
